## Custom Info Box

If you must continuously display a dialog with your plug-in and it need not contain many controls, consider using an inspector (the little gray info boxes at the bottom of the Edit View).

![](../_Readme_Images/inspectorview.png)